@@ -1,13 +1,15 @@
-#' @import Matrix ggplot2 patchwork
+#' @import Matrix ggplot2 ggraph patchwork
 #'
-#' @importFrom Rcpp evalCpp
+#' @importFrom Rcpp evalCpp sourceCpp
 #' @importFrom RcppArmadillo armadillo_version
+#' @importFrom RcppParallel RcppParallelLibs
 #' @importFrom stats coef predict
 #' @importFrom utils methods
 NULL
 
 utils::globalVariables(
   c(
+    "count",
     "x",
     "y",
     "xend",
